@@ -48,10 +48,10 @@ pub mod experiment_device_config;
 pub use self::experiment_device_config::ExperimentDeviceConfig;
 pub mod gcode_file;
 pub use self::gcode_file::GcodeFile;
-pub mod license;
-pub use self::license::License;
-pub mod license_request;
-pub use self::license_request::LicenseRequest;
+pub mod janus_auth;
+pub use self::janus_auth::JanusAuth;
+pub mod janus_auth_request;
+pub use self::janus_auth_request::JanusAuthRequest;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
@@ -122,6 +122,10 @@ pub mod octoprint_python;
 pub use self::octoprint_python::OctoprintPython;
 pub mod octoprint_python_request;
 pub use self::octoprint_python_request::OctoprintPythonRequest;
+pub mod onboarding_task;
+pub use self::onboarding_task::OnboardingTask;
+pub mod onboarding_task_request;
+pub use self::onboarding_task_request::OnboardingTaskRequest;
 pub mod paginated_alert_list;
 pub use self::paginated_alert_list::PaginatedAlertList;
 pub mod paginated_camera_list;
@@ -138,8 +142,8 @@ pub mod paginated_experiment_list;
 pub use self::paginated_experiment_list::PaginatedExperimentList;
 pub mod paginated_gcode_file_list;
 pub use self::paginated_gcode_file_list::PaginatedGcodeFileList;
-pub mod paginated_license_list;
-pub use self::paginated_license_list::PaginatedLicenseList;
+pub mod paginated_janus_auth_list;
+pub use self::paginated_janus_auth_list::PaginatedJanusAuthList;
 pub mod paginated_model_artifact_list;
 pub use self::paginated_model_artifact_list::PaginatedModelArtifactList;
 pub mod paginated_octo_print_backup_list;
@@ -148,6 +152,8 @@ pub mod paginated_octo_print_device_list;
 pub use self::paginated_octo_print_device_list::PaginatedOctoPrintDeviceList;
 pub mod paginated_octo_print_event_list;
 pub use self::paginated_octo_print_event_list::PaginatedOctoPrintEventList;
+pub mod paginated_onboarding_task_list;
+pub use self::paginated_onboarding_task_list::PaginatedOnboardingTaskList;
 pub mod paginated_print_job_event_list;
 pub use self::paginated_print_job_event_list::PaginatedPrintJobEventList;
 pub mod paginated_print_nanny_plugin_event_list;
@@ -158,6 +164,8 @@ pub mod paginated_printer_controller_list;
 pub use self::paginated_printer_controller_list::PaginatedPrinterControllerList;
 pub mod paginated_printer_profile_list;
 pub use self::paginated_printer_profile_list::PaginatedPrinterProfileList;
+pub mod paginated_public_key_list;
+pub use self::paginated_public_key_list::PaginatedPublicKeyList;
 pub mod paginated_remote_command_event_list;
 pub use self::paginated_remote_command_event_list::PaginatedRemoteCommandEventList;
 pub mod paginated_remote_control_command_list;
@@ -186,6 +194,8 @@ pub mod patched_device_calibration_request;
 pub use self::patched_device_calibration_request::PatchedDeviceCalibrationRequest;
 pub mod patched_device_request;
 pub use self::patched_device_request::PatchedDeviceRequest;
+pub mod patched_janus_auth_request;
+pub use self::patched_janus_auth_request::PatchedJanusAuthRequest;
 pub mod patched_octo_print_device_request;
 pub use self::patched_octo_print_device_request::PatchedOctoPrintDeviceRequest;
 pub mod patched_print_session_request;
@@ -194,6 +204,8 @@ pub mod patched_printer_controller_request;
 pub use self::patched_printer_controller_request::PatchedPrinterControllerRequest;
 pub mod patched_printer_profile_request;
 pub use self::patched_printer_profile_request::PatchedPrinterProfileRequest;
+pub mod patched_public_key_request;
+pub use self::patched_public_key_request::PatchedPublicKeyRequest;
 pub mod patched_remote_control_command_request;
 pub use self::patched_remote_control_command_request::PatchedRemoteControlCommandRequest;
 pub mod patched_system_info_request;
@@ -226,8 +238,10 @@ pub mod printer_profile;
 pub use self::printer_profile::PrinterProfile;
 pub mod printer_profile_request;
 pub use self::printer_profile_request::PrinterProfileRequest;
-pub mod printnanny_env_enum;
-pub use self::printnanny_env_enum::PrintnannyEnvEnum;
+pub mod public_key;
+pub use self::public_key::PublicKey;
+pub mod public_key_request;
+pub use self::public_key_request::PublicKeyRequest;
 pub mod release_channel_enum;
 pub use self::release_channel_enum::ReleaseChannelEnum;
 pub mod remote_command_event;
@@ -248,6 +262,8 @@ pub mod system_info_request;
 pub use self::system_info_request::SystemInfoRequest;
 pub mod task;
 pub use self::task::Task;
+pub mod task_enum;
+pub use self::task_enum::TaskEnum;
 pub mod task_request;
 pub use self::task_request::TaskRequest;
 pub mod task_status;
